using Managing.Domain.MoneyManagements;
using Managing.Domain.Users;

namespace Managing.Application.Abstractions.Services
{
    public interface IMoneyManagementService
    {
        Task<MoneyManagement> CreateOrUpdateMoneyManagement(User user, MoneyManagement request);
        Task<MoneyManagement> GetMoneyMangement(User user, string name);
        Task<MoneyManagement> GetMoneyMangement(string name);
        Task<IEnumerable<MoneyManagement>> GetMoneyMangements(User user);
        Task<bool> DeleteMoneyManagement(User user, string name);
        Task<bool> DeleteMoneyManagements(User user);
    }
}